var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { QueryClientProvider } from '@showroomjs/bundles/query';
import { StaticRouter } from '@showroomjs/bundles/routing';
import { flattenArray, isDefined } from '@showroomjs/core';
import { getCssText } from '@showroomjs/ui';
import * as React from 'react';
import * as ReactDOMServer from 'react-dom/server';
import { Helmet } from 'react-helmet';
import sections from 'react-showroom-sections';
import { createQueryClient } from '../lib/create-query-client';
import { factoryMap } from '../lib/lazy';
import { PreviewApp } from './preview-app';
export const ssr = {
    render: ({ pathname }) => __awaiter(void 0, void 0, void 0, function* () {
        for (const [fn] of factoryMap) {
            const result = yield fn();
            factoryMap.set(fn, result.default);
        }
        const queryClient = createQueryClient();
        const result = ReactDOMServer.renderToString(React.createElement(StaticRouter, { location: { pathname }, basename: `${process.env.BASE_PATH}/_preview` },
            React.createElement(QueryClientProvider, { client: queryClient },
                React.createElement(PreviewApp, null))));
        return {
            result,
            cleanup: () => queryClient.clear(),
        };
    }),
    getCssText,
    getHelmet: () => Helmet.renderStatic(),
    getRoutes: () => __awaiter(void 0, void 0, void 0, function* () {
        const result = [];
        const markdownSections = [];
        const componentSections = [];
        function getRoute(section) {
            return __awaiter(this, void 0, void 0, function* () {
                if (section.type === 'group') {
                    yield Promise.all(section.items.map(getRoute));
                }
                if (section.type === 'component') {
                    componentSections.push(section);
                    const { codeblocks } = yield section.data.load();
                    const codeHashes = Object.values(codeblocks)
                        .map((block) => block === null || block === void 0 ? void 0 : block.initialCodeHash)
                        .filter(isDefined);
                    if (codeHashes.length > 0) {
                        result.push(codeHashes.map((hash) => `${hash}/${section.id}/`));
                    }
                }
                if (section.type === 'markdown') {
                    markdownSections.push(section);
                }
            });
        }
        for (const section of sections) {
            yield getRoute(section);
        }
        for (const section of markdownSections) {
            const { codeblocks } = yield section.load();
            const codeHashes = Object.values(codeblocks)
                .map((block) => block === null || block === void 0 ? void 0 : block.initialCodeHash)
                .filter(isDefined);
            if (codeHashes.length > 0) {
                const compName = section._associatedComponentName;
                if (compName) {
                    const compSection = componentSections.find((sec) => sec.metadata.displayName === compName);
                    result.push(codeHashes.map((hash) => compSection ? `${hash}/${compSection.id}/` : hash));
                }
                else {
                    result.push(codeHashes.map((h) => `${h}/`));
                }
            }
        }
        return flattenArray(result);
    }),
};
//# sourceMappingURL=preview-server-entry.js.map