import { Tabs, callAll } from '@showroomjs/ui';
import * as React from 'react';
import { useCodeFrameContext } from '../lib/code-frame-context';
import { getFrameId } from '../lib/get-frame-id';
import { getScrollFn } from '../lib/scroll-into-view';
import { A11yResultContextProvider, useA11yResultByFrame, } from '../lib/use-a11y-result';
import { A11yResultPanel } from './a11y-result-panel';
export const A11yResultPanelForFrames = (props) => {
    const { frameDimensions } = useCodeFrameContext();
    const { resultByFrameName } = useA11yResultByFrame();
    if (frameDimensions.length === 0) {
        return null;
    }
    return frameDimensions.length === 1 ? (React.createElement(React.Fragment, null, frameDimensions.map((frame) => (React.createElement(A11yResultContextProvider, { result: resultByFrameName[frame.name], key: frame.name },
        React.createElement(A11yResultPanel, { highlightItems: (selectors, color) => props.onHighlightItems({
                frameName: frame.name,
                selectors,
                color,
            }) })))))) : (React.createElement(Tabs.Root, { value: props.activeTab, onValueChange: callAll(props.setActiveTab, props.scrollToFrameWhenSelect
            ? (frameName) => {
                const frame = frameDimensions.find((f) => f.name === frameName);
                if (frame) {
                    const frameId = getFrameId(frame);
                    const targetFrame = document.querySelector(`[data-frame-id="${frameId}"]`);
                    if (targetFrame) {
                        getScrollFn().then((scroll) => scroll(targetFrame, {
                            block: 'center',
                            behavior: 'smooth',
                            inline: 'center',
                        }));
                    }
                }
            }
            : undefined, props.resetHiglights) },
        React.createElement(Tabs.List, null, frameDimensions.map((frame) => (React.createElement(Tabs.Trigger, { value: frame.name, key: frame.name }, frame.name)))),
        frameDimensions.map((frame) => (React.createElement(Tabs.Content, { value: frame.name, key: frame.name },
            React.createElement(A11yResultContextProvider, { result: resultByFrameName[frame.name] },
                React.createElement(A11yResultPanel, { highlightItems: (selectors, color) => props.onHighlightItems({
                        frameName: frame.name,
                        selectors,
                        color,
                    }) })))))));
};
//# sourceMappingURL=a11y-result-panel-for-frames.js.map