var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { AdjustmentsIcon, AnnotationIcon, CodeIcon, TemplateIcon, TerminalIcon, ZoomInIcon, } from '@heroicons/react/outline';
import { AnnotationIcon as FilledAnnotationIcon, LocationMarkerIcon, } from '@heroicons/react/solid';
import { isEqualArray, } from '@showroomjs/core';
import { css, DropdownMenu, EditorBottomIcon, EditorRightIcon, IconButton, styled, TextTooltip, ToggleButton, useDebounce, usePersistedState, useQueryParams, } from '@showroomjs/ui';
import * as React from 'react';
import { useCodeFrameContext } from '../lib/code-frame-context';
import { useCodeTheme } from '../lib/code-theme-context';
import { safeCompress, safeDecompress } from '../lib/compress';
import { lazy, Suspense } from '../lib/lazy';
import { getScrollFn } from '../lib/scroll-into-view';
import { A11yResultByFrameContextProvider } from '../lib/use-a11y-result';
import { useCodeCompilationCache } from '../lib/use-code-compilation';
import { useCommentState } from '../lib/use-comment-state';
import { PreviewConsoleProvider } from '../lib/use-preview-console';
import { PropsEditorProvider } from '../lib/use-props-editor';
import { useSize } from '../lib/use-size';
import { useStateWithParams } from '../lib/use-state-with-params';
import { useTargetAudience } from '../lib/use-target-audience';
import { A11yResultPanelForFrames, } from './a11y-result-panel-for-frames';
import { Div } from './base';
import { CheckboxDropdown } from './checkbox-dropdown';
import { CodeEditor } from './code-editor';
import { CodePreviewIframe } from './code-preview-iframe';
import { ConsolePanel } from './console-panel';
import { PropsEditorPanel } from './props-editor-panel';
import { RadioDropdown } from './radio-dropdown';
import { CommentList } from './standalone-code-live-editor-comment';
import { StandaloneCodeLiveEditorCommentPopover } from './standalone-code-live-editor-comment-popover';
import { BtnText, StandaloneCodeLiveEditorCopyButton, } from './standalone-code-live-editor-copy-button';
import { StandaloneCodeLiveEditorPreviewList } from './standalone-code-live-editor-preview';
const CodeAdvancedEditor = lazy(() => import('./code-advanced-editor').then((m) => ({
    default: m.CodeAdvancedEditor,
})));
export const StandaloneCodeLiveEditor = (_a) => {
    var { className } = _a, props = __rest(_a, ["className"]);
    const theme = useCodeTheme();
    const [queryParams, setQueryParams] = useQueryParams();
    const [isCodeParsed, setIsCodeParsed] = React.useState(false);
    const { state: commentState, add, remove, clear, } = useCommentState(props.codeHash);
    const [activeComment, setActiveComment] = React.useState('');
    React.useEffect(() => {
        if (activeComment) {
            let isCurrent = true;
            getScrollFn().then((scroll) => {
                if (isCurrent) {
                    const target = document.querySelector('[data-active-comment]');
                    if (target) {
                        scroll(target, {
                            scrollMode: 'if-needed',
                        });
                    }
                }
            });
            return () => {
                isCurrent = false;
            };
        }
    }, [activeComment]);
    const [code, setCode] = React.useState(props.code);
    const [showEditor, setShowEditor] = useStateWithParams(true, 'hideEditor', (paramValue) => !paramValue);
    const [zoomLevel, setZoomLevel] = useStateWithParams('75', 'zoom', (x) => x);
    const [hiddenSizes, _setHiddenSizes] = usePersistedState([], 'hiddenSizes');
    const setHiddenSizes = (sizes) => {
        _setHiddenSizes(sizes);
        setQueryParams({
            hiddenSizes: sizes.length > 0
                ? sizes.map((s) => `${s[0]}x${s[1]}`).join('_')
                : undefined,
        }, {
            merge: true,
        });
    };
    const { frameDimensions, showDeviceFrame: showDeviceFrameSetting } = useCodeFrameContext();
    const showMultipleScreens = frameDimensions.length > 0;
    const [showDeviceFrame, setShowDeviceFrame] = useStateWithParams(showDeviceFrameSetting, 'showFrame', (value) => value === 'true');
    React.useEffect(() => {
        const codeValue = queryParams.get('code');
        const hiddenSizesValue = queryParams.get('hiddenSizes');
        if (codeValue) {
            setCode(safeDecompress(codeValue, props.code));
        }
        if (hiddenSizesValue) {
            const serializedHiddenSizes = hiddenSizesValue
                .split('_')
                .map((xAndY) => xAndY.split('x').map(Number))
                .filter((v) => v.length === 2 &&
                v.every((n) => !isNaN(n)) &&
                frameDimensions.some((d) => d.width === v[0] && d.height === v[1]));
            if (serializedHiddenSizes.length > 0) {
                _setHiddenSizes(serializedHiddenSizes);
            }
        }
        setIsCodeParsed(true);
    }, []);
    const debouncedCode = useDebounce(code);
    React.useEffect(() => {
        setQueryParams({
            code: debouncedCode !== props.code
                ? safeCompress(debouncedCode)
                : undefined,
        }, { merge: true });
    }, [debouncedCode]);
    const [isCommenting, _setIsCommenting] = useStateWithParams(false, 'commentMode', (v) => !!v);
    const setIsCommenting = (isCommentMode) => {
        _setIsCommenting(isCommentMode, isCommentMode ? 'true' : undefined);
        if (isCommentMode) {
            setIsMeasuring(false);
        }
        else {
            clear();
        }
    };
    const previewListRef = React.useRef(null);
    const [targetCoord, setTargetCoord] = React.useState(undefined);
    const displayedComments = React.useMemo(() => commentState.items.filter((item) => item.zoomLevel === zoomLevel &&
        isEqualArray(item.hiddenSizes, hiddenSizes, { ignoreOrder: true }) &&
        item.showFrame === showDeviceFrame), [commentState.items, zoomLevel, hiddenSizes]);
    const targetAudience = useTargetAudience();
    const [syncState, setSyncState] = usePersistedState(targetAudience === 'developer', 'syncState');
    const [syncScroll, setSyncScroll] = usePersistedState(true, 'syncScroll');
    const [_useAdvancedEditor, setUseAdvancedEditor] = usePersistedState(false, 'useAdvancedEditor');
    const useAdvancedEditor = process.env.ENABLE_ADVANCED_EDITOR && _useAdvancedEditor;
    const [isMeasuring, setIsMeasuring] = React.useState(false);
    const initialCompilation = useCodeCompilationCache(props.code, props.lang);
    const isPropsEditor = React.useMemo(() => initialCompilation.data &&
        initialCompilation.data.type === 'success' &&
        initialCompilation.data.features.some((f) => f.feature === 'propsEditor' && !f.hasRenderEditor), [initialCompilation.data]);
    const [wrapPreview, setWrapPreview] = usePersistedState(false, 'wrapPreview');
    const [editorPosition, setEditorPosition] = usePersistedState('right', 'editorPosition');
    const isDockToRight = editorPosition === 'right';
    const toolbarRef = React.useRef(null);
    const toolbarSize = useSize(toolbarRef);
    const [a11yTab, setA11yTab] = React.useState(() => frameDimensions.length > 0 ? frameDimensions[0].name : '');
    const [higlightedEls, setHighlightedEls] = React.useState(undefined);
    const resetHighlights = () => setHighlightedEls((prev) => prev && Object.assign(Object.assign({}, prev), { selectors: [], color: '' }));
    const codeEditorShouldDisplay = showEditor && !isCommenting && !isPropsEditor;
    return (React.createElement(PreviewConsoleProvider, null,
        React.createElement(A11yResultByFrameContextProvider, null,
            React.createElement(Div, { css: { height: '100%', display: 'flex', flexDirection: 'column' } },
                React.createElement(Toolbar, { style: {
                        top: 'var(--header-height, 0px)',
                    }, ref: toolbarRef },
                    React.createElement(Div, { css: {
                            display: 'flex',
                        } },
                        React.createElement(Div, { css: {
                                display: 'flex',
                                alignItems: 'center',
                                gap: '$2',
                                paddingRight: '$2',
                                borderRight: '1px solid $gray-200',
                            } },
                            React.createElement(TextTooltip, { label: "Comment" },
                                React.createElement(PrimaryToggleButton, { pressed: isCommenting, onPressedChange: setIsCommenting, "data-testid": "comment-toggle" }, isCommenting ? React.createElement(CommentOnIcon, null) : React.createElement(CommentIcon, null))),
                            showMultipleScreens && (React.createElement(React.Fragment, null,
                                React.createElement(DropdownMenu, null,
                                    React.createElement(DropdownMenu.Trigger, { asChild: true },
                                        React.createElement(MenuButton, { "data-testid": "setting-menu" },
                                            React.createElement(ScreensIcon, { width: 20, height: 20 }))),
                                    React.createElement(CheckboxDropdown, null,
                                        React.createElement(DropdownMenu.Label, null, "Screens"),
                                        frameDimensions.map((frame) => {
                                            return (React.createElement(CheckboxDropdown.Item, { checked: !hiddenSizes.some(([w, h]) => w === frame.width && h === frame.height), onCheckedChange: (checked) => {
                                                    if (checked) {
                                                        setHiddenSizes(hiddenSizes.filter((s) => !(s[0] === frame.width &&
                                                            s[1] === frame.height) && frameDimensions.includes(frame)));
                                                    }
                                                    else {
                                                        setHiddenSizes(hiddenSizes.concat([
                                                            [frame.width, frame.height],
                                                        ]));
                                                    }
                                                }, key: frame.name }, frame.name));
                                        }),
                                        React.createElement(DropdownMenu.Separator, null),
                                        showDeviceFrameSetting && (React.createElement(CheckboxDropdown.Item, { checked: showDeviceFrame, onCheckedChange: (showFrame) => setShowDeviceFrame(showFrame, showFrame ? undefined : 'false') }, "Device Frame")),
                                        !isCommenting && (React.createElement(CheckboxDropdown.Item, { checked: wrapPreview, onCheckedChange: setWrapPreview }, "Wrap Screens")),
                                        (showDeviceFrameSetting || !isCommenting) && (React.createElement(DropdownMenu.Separator, null)),
                                        !isCommenting && (React.createElement(CheckboxDropdown.Item, { checked: syncState, onCheckedChange: setSyncState }, process.env.SYNC_STATE_TYPE === 'state'
                                            ? 'Sync State'
                                            : 'Sync Interactions')),
                                        React.createElement(CheckboxDropdown.Item, { checked: syncScroll, onCheckedChange: setSyncScroll }, "Sync Scroll"))),
                                React.createElement(DropdownMenu, null,
                                    React.createElement(DropdownMenu.Trigger, { asChild: true },
                                        React.createElement(MenuButton, null,
                                            React.createElement(BtnText, null,
                                                zoomLevel,
                                                "% "),
                                            React.createElement(ZoomIcon, { width: 20, height: 20 }))),
                                    React.createElement(RadioDropdown, { value: zoomLevel, onChangeValue: (level) => setZoomLevel(level, level === '75' ? undefined : level), options: zoomOptions, className: zoomDropdown(), align: "end" }))))),
                        !isCommenting && (React.createElement(Div, { css: {
                                px: '$1',
                            } },
                            React.createElement(TextTooltip, { label: "Measure" },
                                React.createElement(PrimaryToggleButton, { pressed: isMeasuring, onPressedChange: setIsMeasuring, "data-testid": "measure-toggle" },
                                    React.createElement(MeasureIcon, { active: isMeasuring, width: 20, height: 20 })))))),
                    React.createElement(Div, { css: {
                            display: 'inline-flex',
                            alignItems: 'center',
                            gap: '$1',
                        } },
                        React.createElement(StandaloneCodeLiveEditorCopyButton, { getTextToCopy: () => {
                                if (window) {
                                    return window.location.href;
                                }
                                return '';
                            } }))),
                React.createElement(PropsEditorProvider, { codeHash: props.codeHash, serializeToParam: true },
                    React.createElement(Div, { className: className, css: Object.assign({ display: 'flex', backgroundColor: '$gray-200', flex: 1, flexDirection: 'column' }, (isDockToRight
                            ? {
                                '@md': {
                                    flexDirection: 'row',
                                    width: '100%',
                                    flex: 'none',
                                    height: toolbarSize
                                        ? `calc(100vh - var(--header-height, 64px) - var(--breadcrumb-height, 0px) - ${toolbarSize.height}px)`
                                        : undefined,
                                },
                            }
                            : {})) },
                        React.createElement(Div, { css: isDockToRight
                                ? {
                                    '@md': {
                                        flex: 1,
                                        overflow: 'auto',
                                        overscrollBehavior: 'contain',
                                    },
                                }
                                : undefined },
                            showMultipleScreens ? (React.createElement(StandaloneCodeLiveEditorPreviewList, { code: debouncedCode, lang: props.lang, codeHash: props.codeHash, isCommenting: isCommenting, isMeasuring: isMeasuring, hiddenSizes: hiddenSizes, fitHeight: showDeviceFrame && (!showEditor || isCommenting), zoom: zoomLevel, showFrame: showDeviceFrame, onClickCommentPoint: (coord) => {
                                    const previewList = previewListRef.current;
                                    if (previewList) {
                                        const listRect = previewList.getBoundingClientRect();
                                        const listX = listRect.left + window.pageXOffset;
                                        const listY = listRect.top + window.pageYOffset;
                                        const elementRelative = {
                                            x: coord.x - listX + previewList.scrollLeft,
                                            y: coord.y - listY + previewList.scrollTop,
                                        };
                                        setTargetCoord(elementRelative);
                                        setActiveComment('');
                                    }
                                }, ref: previewListRef, syncState: syncState, syncScroll: syncScroll, onA11ySummaryClick: setA11yTab, a11yHighlightData: higlightedEls, wrapContent: !isCommenting && wrapPreview },
                                isCommenting && targetCoord ? (React.createElement(StandaloneCodeLiveEditorCommentPopover, { open: true, onOpenChange: (shouldOpen) => {
                                        if (!shouldOpen) {
                                            setTargetCoord(undefined);
                                        }
                                    }, onAdd: (newComment) => {
                                        add({
                                            text: newComment,
                                            zoomLevel,
                                            hiddenSizes: hiddenSizes,
                                            left: targetCoord.x,
                                            top: targetCoord.y,
                                            showFrame: showDeviceFrame,
                                        });
                                        setTargetCoord(undefined);
                                    } },
                                    React.createElement(Marker, { css: {
                                            position: 'absolute',
                                            top: targetCoord.y,
                                            left: targetCoord.x,
                                        } }))) : null,
                                isCommenting &&
                                    displayedComments.map((comment) => {
                                        const isActive = comment.id === activeComment;
                                        return (React.createElement(Div, { css: {
                                                position: 'absolute',
                                                top: comment.top,
                                                left: comment.left,
                                                pointerEvents: 'auto',
                                                cursor: 'pointer',
                                                width: 20,
                                                height: 20,
                                                zIndex: 5,
                                            }, key: comment.id },
                                            React.createElement(TextTooltip, { open: isActive, label: comment.text, side: "top", className: commentPopover() },
                                                React.createElement(MarkerButton, { onClick: (ev) => {
                                                        ev.stopPropagation();
                                                        setActiveComment(isActive ? '' : comment.id);
                                                    }, type: "button" },
                                                    React.createElement(Marker, { iconClass: iconClass({
                                                            active: isActive,
                                                        }), "data-active-comment": isActive ? true : null })))));
                                    }),
                                isCommenting && (React.createElement(Div, { onClick: (ev) => ev.stopPropagation(), css: {
                                        position: 'absolute',
                                        bottom: 0,
                                        left: 0,
                                        right: 0,
                                        height: 12,
                                        pointerEvents: 'auto',
                                    } })))) : (React.createElement(CodePreviewIframe, { code: debouncedCode, lang: props.lang, codeHash: props.codeHash })),
                            React.createElement(ConsolePanel, null)),
                        React.createElement(Div, { css: Object.assign({ display: 'flex', background: 'White' }, (isDockToRight
                                ? {
                                    '@md': isCommenting
                                        ? {
                                            minWidth: '23.5rem',
                                        }
                                        : {
                                            width: '30rem',
                                            borderLeft: '1px solid $gray-200',
                                        },
                                }
                                : {})) },
                            React.createElement(Div, { css: Object.assign({ flex: 1 }, (isDockToRight
                                    ? {
                                        '@md': {
                                            display: 'flex',
                                            flexDirection: 'column',
                                        },
                                    }
                                    : {})) },
                                !isCommenting && isPropsEditor && React.createElement(PropsEditorPanel, null),
                                codeEditorShouldDisplay &&
                                    (useAdvancedEditor ? (isCodeParsed && (React.createElement(Div, { css: Object.assign({ flex: 1, overflow: 'hidden', height: `${code.split(/\r\n|\r|\n/).length + 3}rem` }, (isDockToRight
                                            ? {
                                                '@md': {
                                                    height: '100%',
                                                },
                                            }
                                            : {})) },
                                        React.createElement(AdvancedEditor, { value: code, onChange: setCode, language: props.lang, initialResult: initialCompilation.data, key: isDockToRight ? 0 : 1 })))) : (React.createElement(CodeEditor, { code: code, onChange: setCode, language: props.lang, theme: theme, className: editor(), wrapperClass: editorWrapper() }))),
                                !isCommenting && (React.createElement(A11yPanel, { activeTab: a11yTab, setActiveTab: setA11yTab, onHighlightItems: setHighlightedEls, resetHiglights: resetHighlights, scrollToFrameWhenSelect: isDockToRight }))),
                            isCommenting && (React.createElement(Div, { css: {
                                    width: '100%',
                                    backgroundColor: '$gray-100',
                                    height: 200,
                                    '@md': isDockToRight
                                        ? {
                                            height: '100%',
                                        }
                                        : {},
                                } }, commentState.items.length > 0 ? (React.createElement(CommentList, null, commentState.items.map((comment) => (React.createElement(CommentList.Item, { active: comment.id === activeComment, onClick: () => {
                                    setHiddenSizes(comment.hiddenSizes);
                                    setZoomLevel(comment.zoomLevel, comment.zoomLevel === '100'
                                        ? undefined
                                        : comment.zoomLevel);
                                    if (showDeviceFrameSetting) {
                                        setShowDeviceFrame(comment.showFrame, comment.showFrame ? undefined : 'false');
                                    }
                                    setActiveComment(comment.id);
                                }, onDismiss: () => remove(comment.id), key: comment.id }, comment.text))))) : (React.createElement(NoCommentMsg, null,
                                "No comment added.",
                                React.createElement("br", null),
                                "Click on any point of the preview",
                                React.createElement("br", null),
                                " to start adding comment.")))),
                            React.createElement(Div, { css: {
                                    display: 'flex',
                                    flexFlow: 'column',
                                    gap: '$2',
                                    padding: '$2',
                                    borderLeft: '1px solid $gray-200',
                                } },
                                React.createElement(TextTooltip, { label: isDockToRight ? 'Dock to right' : 'Dock to bottom' },
                                    React.createElement(IconButton, { "data-testid": "editor-position-button", onClick: () => setEditorPosition(editorPosition === 'bottom' ? 'right' : 'bottom'), css: {
                                            display: 'none',
                                            '@md': {
                                                display: 'inline-flex',
                                            },
                                        } }, isDockToRight ? (React.createElement(EditorRightIcon, null)) : (React.createElement(EditorBottomIcon, null)))),
                                !isCommenting && !isPropsEditor && (React.createElement(TextTooltip, { label: "Code Editor" },
                                    React.createElement(ToggleButton, { pressed: showEditor, onPressedChange: (show) => setShowEditor(show, show ? undefined : 'true'), css: showEditor
                                            ? {
                                                color: '$gray-600',
                                                backgroundColor: '$gray-100',
                                                shadow: 'inner',
                                            }
                                            : {
                                                color: '$gray-400',
                                            }, "data-testid": "editor-toggle" },
                                        React.createElement(CodeIcon, { width: 24, height: 24 })))),
                                process.env.ENABLE_ADVANCED_EDITOR &&
                                    codeEditorShouldDisplay && (React.createElement(TextTooltip, { label: "Advanced Editor" },
                                    React.createElement(ToggleButton, { pressed: useAdvancedEditor, onPressedChange: setUseAdvancedEditor, css: Object.assign({ display: 'none', '@md': {
                                                display: 'flex',
                                            } }, (useAdvancedEditor
                                            ? {
                                                color: '$gray-600',
                                                backgroundColor: '$gray-100',
                                                shadow: 'inner',
                                            }
                                            : {
                                                color: '$gray-400',
                                            })), "data-testid": "advanced-editor-toggle" },
                                        React.createElement(TerminalIcon, { width: 24, height: 24 }))))))))))));
};
const NoCommentMsg = styled('p', {
    margin: '$1',
    padding: '$2',
    color: '$gray-500',
    textAlign: 'center',
});
const A11yPanel = (props) => (React.createElement(A11yPanelRoot, null,
    React.createElement(A11yPanelTitle, null, "Accessibility"),
    React.createElement(A11yResultPanelForFrames, Object.assign({}, props))));
const A11yPanelRoot = styled('section', {
    px: '$2',
    paddingBottom: '$3',
    minHeight: 200,
    maxHeight: '40vh',
    overflowY: 'auto',
});
const A11yPanelTitle = styled('div', {
    fontSize: '$lg',
    lineHeight: '$lg',
    fontWeight: '500',
    px: '$2',
    paddingBottom: '$1',
    paddingTop: '$2',
    borderTop: '1px solid $gray-200',
});
function AdvancedEditor(props) {
    if (process.env.ENABLE_ADVANCED_EDITOR) {
        return (React.createElement(Suspense, { fallback: null },
            React.createElement(CodeAdvancedEditor, Object.assign({}, props))));
    }
    return null;
}
const zoomOptions = [
    {
        value: '20',
        label: '20%',
    },
    {
        value: '30',
        label: '30%',
    },
    {
        value: '40',
        label: '40%',
    },
    {
        value: '50',
        label: '50%',
    },
    {
        value: '75',
        label: '75%',
    },
    {
        value: '100',
        label: '100%',
    },
    {
        value: '110',
        label: '110%',
    },
    {
        value: '125',
        label: '125%',
    },
];
const zoomDropdown = css({
    minWidth: '80px !important',
});
const MarkerInner = styled(LocationMarkerIcon, {
    width: 20,
    height: 20,
    color: '$gray-500',
});
const MarkerSpan = React.forwardRef(function MarkerSpan(_a, forwardedRef) {
    var { iconClass } = _a, props = __rest(_a, ["iconClass"]);
    return (React.createElement("span", Object.assign({}, props, { ref: forwardedRef }),
        React.createElement(MarkerInner, { width: 20, height: 20, className: iconClass })));
});
const PrimaryToggleButton = styled(ToggleButton, {
    '&[aria-pressed="true"]': {
        backgroundColor: '$primary-700',
    },
});
const Marker = styled(MarkerSpan, {
    display: 'inline-block',
    width: 20,
    height: 20,
});
const MarkerButton = styled('button', {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    margin: '-10px',
    width: 40,
    height: 40,
    outlineRing: '',
    borderRadius: '$lg',
});
const Toolbar = styled('div', {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
    px: '$3',
    backgroundColor: 'White',
    borderBottom: '1px solid $gray-200',
    '@lg': {
        position: 'sticky',
        zIndex: 10,
    },
});
const CommentIcon = styled(AnnotationIcon, {
    width: 20,
    height: 20,
    color: '$gray-400',
});
const CommentOnIcon = styled(FilledAnnotationIcon, {
    width: 20,
    height: 20,
    color: 'White',
});
const MeasureIcon = styled(TemplateIcon, {
    width: 20,
    height: 20,
    color: '$gray-400',
    variants: {
        active: {
            true: {
                color: 'White',
            },
        },
    },
});
const ZoomIcon = styled(ZoomInIcon, {
    width: 20,
    height: 20,
    color: '$gray-400',
});
const ScreensIcon = styled(AdjustmentsIcon, {
    width: 20,
    height: 20,
    color: '$gray-400',
});
const MenuButton = styled('button', {
    display: 'inline-flex',
    alignItems: 'center',
    gap: '$1',
    fontSize: '$sm',
    lineHeight: '$sm',
    px: '$2',
    py: '$1',
    borderRadius: '$sm',
    outlineRing: '$primary-200',
});
const editorWrapper = css({
    flex: 1,
    overflow: 'auto',
});
const editor = css({
    borderRadius: '$base',
});
const commentPopover = css({
    whiteSpace: 'pre-wrap',
});
const iconClass = css({
    transform: 'scale(1)',
    transition: 'transform 150ms ease-in-out',
    transformOrigin: 'bottom center',
    variants: {
        active: {
            true: {
                color: '$primary-500',
                transform: 'scale(1.5)',
            },
        },
    },
});
//# sourceMappingURL=standalone-code-live-editor.js.map