import { useQueryParams, useStableCallback } from '@showroomjs/ui';
import * as React from 'react';
export const useStateWithParams = (initialState, paramKey, transformParam) => {
    const transformFn = useStableCallback(transformParam);
    const [value, setValue] = React.useState(initialState);
    const [queryParams, setQueryParams] = useQueryParams();
    React.useEffect(() => {
        const val = queryParams.get(paramKey);
        if (val) {
            setValue(transformFn(val));
        }
    }, []);
    const setFn = React.useCallback((newValue, paramValue) => {
        setValue(newValue);
        setQueryParams({
            [paramKey]: paramValue || undefined,
        }, {
            merge: true,
        });
    }, [paramKey, setQueryParams]);
    return [value, setFn];
};
//# sourceMappingURL=use-state-with-params.js.map