"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDevServer = void 0;
const tslib_1 = require("tslib");
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const webpack_dev_server_1 = tslib_1.__importDefault(require("webpack-dev-server"));
const create_webpack_config_1 = require("../config/create-webpack-config");
const createDevServer = (config, options) => {
    const { assetDir, basePath } = config;
    const webpackConfig = (0, create_webpack_config_1.createClientWebpackConfig)('development', config, {
        measure: options.measure,
        operation: 'serve',
    });
    const devServerOptions = Object.assign({
        port: options.port,
        host: options.host,
        client: {
            logging: 'none',
        },
        hot: true,
        historyApiFallback: {
            rewrites: [
                {
                    from: new RegExp(`^\\${basePath}/_preview/`),
                    to: `${basePath}/_preview.html`,
                },
                { from: /./, to: `${basePath}/index.html` },
            ],
        },
    }, assetDir
        ? {
            static: {
                directory: assetDir,
                watch: true,
                publicPath: `${config.basePath}/`,
            },
        }
        : {});
    const compiler = (0, webpack_1.default)(webpackConfig);
    const server = new webpack_dev_server_1.default(devServerOptions, compiler);
    return server;
};
exports.createDevServer = createDevServer;
//# sourceMappingURL=create-dev-server.js.map