"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDocParser = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const docgen = tslib_1.__importStar(require("react-docgen-typescript"));
const ts = tslib_1.__importStar(require("typescript"));
const create_hash_1 = require("./create-hash");
function createDocParser(options) {
    const docgenParser = docgen.withCustomConfig(options.tsconfigPath, options.parserOptions);
    const tsConfigFile = getTSConfigFile(options.tsconfigPath);
    let languageService;
    const fileCache = new Map();
    return {
        parse: (filePath, content) => {
            fileCache.set(filePath, { version: content, text: content });
            const parseResults = docgenParser.parseWithProgramProvider(filePath, function () {
                const currentProgram = languageService && languageService.getProgram();
                if (currentProgram) {
                    return currentProgram;
                }
                const serviceHost = createServiceHost(tsConfigFile.options, fileCache);
                languageService = ts.createLanguageService(serviceHost, ts.createDocumentRegistry());
                return languageService.getProgram();
            });
            const parseResult = parseResults[0];
            return (parseResult &&
                Object.assign({ id: (0, create_hash_1.createHash)(parseResult.filePath) }, parseResult));
        },
    };
}
exports.createDocParser = createDocParser;
function getTSConfigFile(tsconfigPath) {
    const basePath = path.dirname(tsconfigPath);
    const configFile = ts.readConfigFile(tsconfigPath, ts.sys.readFile);
    return ts.parseJsonConfigFileContent(configFile.config, ts.sys, basePath, {}, tsconfigPath);
}
function createServiceHost(compilerOptions, files) {
    return {
        getScriptFileNames: () => {
            return [...files.keys()];
        },
        getScriptVersion: (fileName) => {
            const file = files.get(fileName);
            return (file && file.version.toString()) || '';
        },
        getScriptSnapshot: (fileName) => {
            if (!fs.existsSync(fileName)) {
                return undefined;
            }
            let file = files.get(fileName);
            if (file === undefined) {
                const text = fs.readFileSync(fileName, 'utf-8');
                file = { version: 0, text };
                files.set(fileName, file);
            }
            return ts.ScriptSnapshot.fromString(file.text);
        },
        getCurrentDirectory: () => process.cwd(),
        getCompilationSettings: () => compilerOptions,
        getDefaultLibFileName: (options) => ts.getDefaultLibFilePath(options),
        fileExists: ts.sys.fileExists,
        readFile: ts.sys.readFile,
        readDirectory: ts.sys.readDirectory,
    };
}
//# sourceMappingURL=create-doc-parser.js.map