"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeWebpackConfig = void 0;
const tslib_1 = require("tslib");
const isFunction_1 = tslib_1.__importDefault(require("lodash/isFunction"));
const omit_1 = tslib_1.__importDefault(require("lodash/omit"));
const webpack_merge_1 = require("webpack-merge");
const IGNORE_SECTIONS = ['entry', 'externals', 'output', 'watch', 'stats'];
const IGNORE_SECTIONS_ENV = {
    development: [],
    // For production builds, we'll ignore devtool settings to avoid
    // source mapping bloat.
    production: ['devtool'],
};
const IGNORE_PLUGINS = [
    'CommonsChunkPlugins',
    'MiniCssExtractPlugin',
    'OccurrenceOrderPlugin',
    'DedupePlugin',
    'UglifyJsPlugin',
    'TerserPlugin',
    'HotModuleReplacementPlugin',
];
const merge = (0, webpack_merge_1.mergeWithCustomize)({
    // Ignore user’s plugins to avoid duplicates and issues with our plugins
    customizeArray: (0, webpack_merge_1.unique)('plugins', IGNORE_PLUGINS, (plugin) => plugin.constructor && plugin.constructor.name),
});
/**
 * Merge two Webpack configs.
 *
 * In the user config:
 * - Ignores given sections (options.ignore).
 * - Ignores plugins that shouldn’t be used twice or may cause issues.
 */
function mergeWebpackConfig(baseConfig, userConfig, env = 'production') {
    const userConfigObject = (0, isFunction_1.default)(userConfig)
        ? userConfig(env)
        : userConfig;
    const safeUserConfig = (0, omit_1.default)(userConfigObject, IGNORE_SECTIONS.concat(IGNORE_SECTIONS_ENV[env]));
    return merge(baseConfig, safeUserConfig);
}
exports.mergeWebpackConfig = mergeWebpackConfig;
//# sourceMappingURL=merge-webpack-config.js.map