"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputClientBundle = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@showroomjs/core");
const fs = tslib_1.__importStar(require("fs-extra"));
const path = tslib_1.__importStar(require("path"));
const webpack_1 = tslib_1.__importDefault(require("webpack"));
const create_webpack_config_1 = require("../config/create-webpack-config");
const paths_1 = require("./paths");
async function outputClientBundle(config, profile = false, measure = false) {
    const webpackConfig = (0, create_webpack_config_1.createClientWebpackConfig)('production', config, {
        outDir: config.outDir,
        profileWebpack: profile,
        measure,
        operation: 'build',
    });
    const compiler = (0, webpack_1.default)(webpackConfig);
    try {
        await new Promise((fulfill, reject) => {
            compiler.run((err, stats) => {
                if (err || stats?.hasErrors()) {
                    if (err) {
                        console.error(err);
                    }
                    compiler.close(() => {
                        console.error('Fix the error and try again.');
                    });
                    reject(err);
                }
                compiler.close(() => {
                    fulfill();
                });
            });
        });
        const { manifest } = config.theme;
        if (manifest) {
            await fs.outputJSON((0, paths_1.resolveApp)(`${config.outDir}/manifest.json`), (0, core_1.omit)(manifest, ['baseIconPath']));
            if (manifest.baseIconPath) {
                await fs.copy((0, paths_1.resolveApp)(manifest.baseIconPath), (0, paths_1.resolveApp)(`${config.outDir}/_icons/${path.parse(manifest.baseIconPath).base}`));
            }
        }
    }
    catch (err) {
        console.error(err);
    }
}
exports.outputClientBundle = outputClientBundle;
//# sourceMappingURL=output-client-bundle.js.map