"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prerenderPreview = exports.prerenderSite = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs-extra"));
const log_to_stdout_1 = require("./log-to-stdout");
const paths_1 = require("./paths");
/**
 *
 * @returns number of pre-rendered pages
 */
async function prerenderSite(config, tmpDir) {
    const prerenderCodePath = `${tmpDir}/server/prerender.js`;
    const htmlPath = (0, paths_1.resolveApp)(`${config.outDir}/index.html`);
    const { ssr } = require(prerenderCodePath);
    const template = await fs.readFile(htmlPath, 'utf-8');
    const routes = await ssr.getRoutes();
    if (config.basePath !== '') {
        (0, log_to_stdout_1.logToStdout)(`Prerender with basePath: ${config.basePath}`);
    }
    let pageCount = 0;
    for (const route of routes) {
        if (route !== '') {
            pageCount++;
            await fs.outputFile((0, paths_1.resolveApp)(`${config.outDir}/${route}index.html`), await getHtml(`/${route}`));
        }
    }
    await fs.outputFile((0, paths_1.resolveApp)(`${config.outDir}/_offline.html`), await getHtml('/_offline'));
    await fs.outputFile(htmlPath, await getHtml('/'));
    async function getHtml(pathname) {
        const prerenderResult = await ssr.render({ pathname });
        const helmet = ssr.getHelmet();
        const finalHtml = template
            .replace('<!--SSR-style-->', `<style id="stitches">${ssr.getCssText()}</style>`)
            .replace('<!--SSR-helmet-->', `${helmet.title.toString()}${helmet.meta.toString()}${helmet.link.toString()}`)
            .replace('<!--SSR-target-->', prerenderResult.result);
        prerenderResult.cleanup();
        return finalHtml;
    }
    return pageCount + 1;
}
exports.prerenderSite = prerenderSite;
/**
 *
 * @returns number of pre-rendered pages
 */
async function prerenderPreview(config, tmpDir) {
    const prerenderCodePath = `${tmpDir}/server/previewPrerender.js`;
    const htmlPath = (0, paths_1.resolveApp)(`${config.outDir}/_preview.html`);
    const { ssr } = require(prerenderCodePath);
    const template = await fs.readFile(htmlPath, 'utf-8');
    const routes = await ssr.getRoutes();
    let pageCount = 0;
    for (const route of routes) {
        if (route !== '') {
            pageCount++;
            await fs.outputFile((0, paths_1.resolveApp)(`${config.outDir}/_preview/${route}index.html`), await getHtml(`/${route}`));
        }
    }
    async function getHtml(pathname) {
        const prerenderResult = await ssr.render({ pathname });
        const helmet = ssr.getHelmet();
        const finalHtml = template
            .replace('<!--SSR-style-->', `<style id="stitches">${ssr.getCssText()}</style>`)
            .replace('<!--SSR-helmet-->', `${helmet.title.toString()}${helmet.meta.toString()}${helmet.link.toString()}`)
            .replace('<!--SSR-target-->', prerenderResult.result);
        prerenderResult.cleanup();
        return finalHtml;
    }
    return pageCount;
}
exports.prerenderPreview = prerenderPreview;
//# sourceMappingURL=prerender.js.map