"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildShowroom = void 0;
const tslib_1 = require("tslib");
require('source-map-support').install();
const fs = tslib_1.__importStar(require("fs-extra"));
const perf_hooks_1 = require("perf_hooks");
const generate_dts_1 = require("../lib/generate-dts");
const get_config_1 = require("../lib/get-config");
const log_to_stdout_1 = require("../lib/log-to-stdout");
const output_client_bundle_1 = require("../lib/output-client-bundle");
const output_ssr_bundle_1 = require("../lib/output-ssr-bundle");
const paths_1 = require("../lib/paths");
const prerender_1 = require("../lib/prerender");
async function buildShowroom(userConfig, configFile, profile, measure, { basePath, outDir, } = {}) {
    const config = (0, get_config_1.getConfig)('production', {
        configFile,
        userConfig,
        basePath,
        outDir,
    });
    if (config.example.enableAdvancedEditor) {
        await (0, generate_dts_1.generateDts)(config);
    }
    const ssrDir = (0, paths_1.resolveShowroom)(`ssr-result-${Date.now() + perf_hooks_1.performance.now()}`);
    try {
        if (profile) {
            await (0, output_client_bundle_1.outputClientBundle)(config, profile, measure);
            await (0, output_ssr_bundle_1.outputSSrBundle)(config, ssrDir, profile, measure);
        }
        else {
            await Promise.all([
                (0, output_client_bundle_1.outputClientBundle)(config, profile, measure),
                (0, output_ssr_bundle_1.outputSSrBundle)(config, ssrDir, profile, measure),
            ]);
            (0, log_to_stdout_1.logToStdout)('Prerendering...');
            const [sitePageCount, previewPageCount] = await Promise.all([
                (0, prerender_1.prerenderSite)(config, ssrDir),
                (0, prerender_1.prerenderPreview)(config, ssrDir),
            ]);
            (0, log_to_stdout_1.logToStdout)((0, log_to_stdout_1.green)(`Prerendered ${sitePageCount + previewPageCount} pages.`));
            (0, log_to_stdout_1.logToStdout)(`Generated showroom at`);
            (0, log_to_stdout_1.logToStdout)(`  -  ${(0, log_to_stdout_1.green)((0, paths_1.resolveApp)(config.outDir))}`);
        }
    }
    finally {
        await fs.remove(ssrDir);
    }
}
exports.buildShowroom = buildShowroom;
//# sourceMappingURL=build-showroom.js.map