"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startDevServer = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const create_dev_server_1 = require("../lib/create-dev-server");
const generate_dts_1 = require("../lib/generate-dts");
const get_config_1 = require("../lib/get-config");
const log_to_stdout_1 = require("../lib/log-to-stdout");
const prepare_url_1 = require("../lib/prepare-url");
const { openBrowser } = require(path_1.default.resolve(__dirname, '..', '..', 'open-browser', 'open-browser.js'));
async function startDevServer(userConfig, configFile, measure, port) {
    (0, log_to_stdout_1.logToStdout)('Starting dev server...');
    const config = (0, get_config_1.getConfig)('development', { configFile, userConfig });
    const { devServerPort, example } = config;
    if (example.enableAdvancedEditor) {
        await (0, generate_dts_1.generateDts)(config, { watch: true });
    }
    const HOST = '0.0.0.0';
    const PORT = Number(port ?? process.env.PORT ?? devServerPort);
    const server = (0, create_dev_server_1.createDevServer)(config, { measure, host: HOST, port: PORT });
    await server.start();
    const urls = (0, prepare_url_1.prepareUrls)('http', HOST, PORT, `${config.basePath}/`);
    openBrowser(urls.localUrlForBrowser);
    (0, log_to_stdout_1.logToStdout)(`Dev server available at ${urls.localUrlForTerminal}`);
    return server;
}
exports.startDevServer = startDevServer;
//# sourceMappingURL=start-dev-server.js.map