"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rehypeCodeAutoId = void 0;
const visit = require('unist-util-visit');
const create_hash_1 = require("../lib/create-hash");
var defaultPrefix = 'code';
let count = 1;
/**
 * This plugin generate a unique id for all `<code>` tag so we can use
 * it as a unique key to identify them for focus mode.
 */
function rehypeCodeAutoId({ prefix = defaultPrefix } = {}) {
    return transformer;
    function transformer(tree) {
        visit(tree, 'element', function onElement(node) {
            if (node.tagName === 'code') {
                node.properties = node.properties || {};
                node.properties.id = node.properties.id || generateId(node);
            }
        });
    }
    function generateId(node) {
        const firstTextChild = node.children.find((child) => child.type === 'text');
        return firstTextChild
            ? (0, create_hash_1.createHash)(firstTextChild.value)
            : `${prefix}-${count++}`;
    }
}
exports.rehypeCodeAutoId = rehypeCodeAutoId;
//# sourceMappingURL=rehype-code-auto-id.js.map